@@ -537,12 +537,15 @@ def check_for_project(path: Union[Path, str] = ".") -> Optional[Path]:
         structure_config = _load_project_structure_config(folder)
         contracts = folder.joinpath(structure_config["contracts"])
         interfaces = folder.joinpath(structure_config["interfaces"])
+        scripts = folder.joinpath(structure_config["scripts"])
         tests = folder.joinpath(structure_config["tests"])
 
         if next((i for i in contracts.glob("**/*") if i.suffix in (".vy", ".sol")), None):
             return folder
         if next((i for i in interfaces.glob("**/*") if i.suffix in (".json", ".vy", ".sol")), None):
             return folder
+        if next((i for i in scripts.glob("**/*") if i.suffix in (".py")), None):
+            return folder
         if contracts.is_dir() and tests.is_dir():
             return folder
 
@@ -704,9 +707,15 @@ def load(project_path: Union[Path, str, None] = None, name: Optional[str] = None
                 "which is different from the current working directory",
                 BrownieEnvironmentWarning,
             )
+    else:
+        project_path = Path(project_path)
+        if project_path.resolve() != check_for_project(project_path):
+            packages_path = _get_data_folder().joinpath("packages")
+            if not project_path.is_absolute() and packages_path.joinpath(project_path).exists():
+                project_path = packages_path.joinpath(project_path)
+            else:
+                project_path = None
 
-    elif Path(project_path).resolve() != check_for_project(project_path):
-        project_path = None
     if project_path is None:
         raise ProjectNotFound("Could not find Brownie project")
 
